@@ -29,9 +29,10 @@ from pwd import getpwnam
 import getpass
 import ovirtsdk4
 from ovirt_iso_uploader import config
+from glfs_api import GlfsApi
 
 APP_NAME = "ovirt-iso-uploader"
-VERSION = "4.0.2"
+VERSION = "4.1.0"
 DEFAULT_IMAGES_DIR = 'images/11111111-1111-1111-1111-111111111111'
 NFS_MOUNT_OPTS = '-t nfs -o rw,sync,soft'
 NFS_UMOUNT_OPTS = '-t nfs -f '
@@ -1146,6 +1147,18 @@ class ISOUploader(object):
                     'through SSH'
                 ),
             )
+        elif domain_type in ('glusterfs',):
+            # Glusterfs support
+            for filename in self.configuration.files:
+                remote = "%s/%s/%s" % (id, DEFAULT_IMAGES_DIR, filename)
+                logging.info(_("Start uploading %s "), filename)
+                try:
+                    fs = GlfsApi(address, path)
+                    fs.upload(filename, remote)
+                    fs.umount()
+                except Exception, e:
+                    ExitCodes.exit_code = ExitCodes.CRITICAL
+                    logging.error(e)
         else:
             # NFS support.
             tmpDir = tempfile.mkdtemp()
